=============================
Backup/Restore and DR service
=============================

.. toctree::
   :maxdepth: 2

   get_started.rst
   install.rst
   verify.rst
   next-steps.rst
   api_routes.rst
   metadata_structure.rst
   client_structure.rst
   api_documents.rst
   known_issues.rst


This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial
<https://docs.openstack.org/project-install-guide/ocata/>`_.